@@ -62,8 +62,10 @@ setLT.Fixed=function(LT,n,j,y,weights,nLT,saveAt,rmExistingFiles)
     #Objects for saving posterior means from MCMC
     LT$b=rep(0,LT$p)
     LT$post_b=rep(0,LT$p)
-    LT$post_b2=rep(0,LT$p)
-    fname=paste(saveAt,"ETA_",j,"_b.dat",sep="")
+    LT$post_b2=rep(0,LT$p)   
+
+    fname=paste(saveAt,LT$Name,"_b.dat",sep="")
+
     LT$NamefileOut=fname; 
 
     if(rmExistingFiles)
@@ -139,7 +141,8 @@ setLT.BRR=function(LT,y,n,j,weights,nLT,R2,saveAt,rmExistingFiles)
     LT$varB=LT$S0/(LT$df0+2)
     LT$post_varB=0                 
     LT$post_varB2=0
-    fname=paste(saveAt,"ETA_",j,"_varB.dat",sep=""); 
+    
+    fname=paste(saveAt,LT$Name,"_varB.dat",sep=""); 
     
     if(rmExistingFiles)
     { 
@@ -239,7 +242,8 @@ setLT.BRR_windows=function(LT,y,n,j,weights,nLT,R2,saveAt,rmExistingFiles)
     LT$varB=rep(LT$S0/(LT$df0+2),LT$p)
     LT$post_varB=0                 
     LT$post_varB2=0
-    fname=paste(saveAt,"ETA_",j,"_varB.dat",sep=""); 
+
+    fname=paste(saveAt,LT$Name,"_varB.dat",sep=""); 
     
     if(rmExistingFiles)
     { 
@@ -316,7 +320,7 @@ setLT.BL=function(LT,y,n,j,weights,nLT,R2,saveAt,rmExistingFiles)
 		LT$type="gamma"
 		cat(paste("  By default, the prior density of lambda^2 in the LP ",j,"  was set to gamma.\n",sep=""))
     }else{
-		if(!LT$type%in%c("gamma","beta","fixed")) stop(" The prior for lambda^2 should be gamma, beta or a point of mass (i.e., fixed lambda).\n")
+		if(!LT$type%in%c("gamma","beta","FIXED")) stop(" The prior for lambda^2 should be gamma, beta or a point of mass (i.e., fixed lambda).\n")
     }
     if(LT$type=="gamma")
     {
@@ -368,7 +372,7 @@ setLT.BL=function(LT,y,n,j,weights,nLT,R2,saveAt,rmExistingFiles)
     LT$post_tau2=0  
     LT$post_lambda=0
     
-    fname=paste(saveAt,"ETA_",j,"_lambda.dat",sep="");
+    fname=paste(saveAt,LT$Name,"_lambda.dat",sep="");
     
     if(rmExistingFiles)
     { 
@@ -469,7 +473,7 @@ setLT.RKHS=function(LT,y,n,j,weights,saveAt,R2,nLT,rmExistingFiles)
     LT$uStar=rep(0, LT$levelsU)
     
     #Output files
-    fname=paste(saveAt,"ETA_",j,"_varU.dat",sep="")
+    fname=paste(saveAt,LT$Name,"_varU.dat",sep="")
     LT$NamefileOut=fname; 
 
     if(rmExistingFiles)
@@ -573,10 +577,11 @@ setLT.BayesBandC=function(LT,y,n,j,weights,saveAt,R2,nLT,rmExistingFiles)
   	}
         LT$S=LT$S0
   	LT$varB = LT$varB=rep(LT$S0/(LT$df0+2),LT$p)
-        fname=paste(saveAt,"ETA_",j,"_parBayesB.dat",sep="")
+        fname=paste(saveAt,LT$Name,"_parBayesB.dat",sep="")
   }else{
 	LT$varB = LT$S0
-	fname=paste(saveAt,"ETA_",j,"_parBayesC.dat",sep="")
+	fname=paste(saveAt,LT$Name,"_parBayesC.dat",sep="")
+        
   }
 
   LT$X=as.vector(LT$X)
@@ -587,6 +592,7 @@ setLT.BayesBandC=function(LT,y,n,j,weights,saveAt,R2,nLT,rmExistingFiles)
   }
 
   LT$fileOut=file(description=fname,open="w")
+  LT$NamefileOut=fname;
   
   if(model=="BayesB")
   {
@@ -668,12 +674,14 @@ setLT.BayesA=function(LT,y,n,j,weights,saveAt,R2,nLT,rmExistingFiles)
   LT$varB=rep(LT$S0/(LT$df0+2),LT$p)
   
   # Add one file when S0 is treated as random.
-  fname=paste(saveAt,"ETA_",j,"_ScaleBayesA.dat",sep="") 
+  fname=paste(saveAt,LT$Name,"_ScaleBayesA.dat",sep="") 
   if(rmExistingFiles)
   { 
     unlink(fname) 
   }
+
   LT$fileOut=file(description=fname,open="w")
+  LT$NamefileOut=fname;
     
   LT$X=as.vector(LT$X)
   
@@ -697,12 +705,12 @@ welcome=function()
   cat("\n");
   cat("#--------------------------------------------------------------------#\n");
   cat("#        _\\\\|//_                                                     #\n");
-  cat("#       (` o-o ')      BGLR v1.0.2 build 78                          #\n");
+  cat("#       (` o-o ')      BGLR v1.0.3 build 90                          #\n");
   cat("#------ooO-(_)-Ooo---------------------------------------------------#\n");
   cat("#                      Bayesian Generalized Linear Regression        #\n");
   cat("#                      Gustavo de los Campos, gdeloscampos@gmail.com #\n");
   cat("#    .oooO     Oooo.   Paulino Perez, perpdgo@gmail.com              #\n");
-  cat("#    (   )     (   )   October, 2013                                 #\n");
+  cat("#    (   )     (   )   June, 2014                                    #\n");
   cat("#_____\\ (_______) /_________________________________________________ #\n");
   cat("#      \\_)     (_/                                                   #\n");
   cat("#                                                                    #\n");
@@ -764,7 +772,7 @@ metropLambda=function (tau2, lambda, shape1 = 1.2, shape2 = 1.2, max = 200, ncp
     stop("This package requires R 2.15.0 or later")
   assign(".BGLR.home", file.path(library, pkg),
          pos=match("package:BGLR", search()))
-  BGLR.version = "1.0.2 (2013-10-15), build 78"
+  BGLR.version = "1.0.3 (2014-06-04), build 90"
   assign(".BGLR.version", BGLR.version, pos=match("package:BGLR", search()))
   if(interactive())
   {
@@ -876,7 +884,12 @@ BGLR=function (y, response_type = "gaussian", a = NULL, b = NULL,
     S0 = NULL, df0 = 5, R2 = 0.5, weights = NULL, 
     verbose = TRUE, rmExistingFiles = TRUE) 
 {
-    welcome()
+   
+    if(verbose)
+    {
+	welcome()
+    }
+
     IDs=names(y)
     if (!(response_type %in% c("gaussian", "ordinal")))  stop(" Only gaussian and ordinal responses are allowed\n")
 
@@ -954,7 +967,7 @@ BGLR=function (y, response_type = "gaussian", a = NULL, b = NULL,
         post_threshold = 0
         post_threshold2 = 0
         
-	    post_prob=matrix(nrow=n,ncol=nclass,0)
+	post_prob=matrix(nrow=n,ncol=nclass,0)
         post_prob2=post_prob
     }
 
@@ -995,13 +1008,29 @@ BGLR=function (y, response_type = "gaussian", a = NULL, b = NULL,
     fileOutVarE = file(description = fname, open = "w")
 
     nLT = ifelse(is.null(ETA), 0, length(ETA))
+    
 
     #Setting the linear terms
     if (nLT > 0) {
-        for (i in 1:nLT) {
+	
+	if(is.null(names(ETA)))
+    	{ 
+             names(ETA)<-rep("",nLT)
+    	}
+
+        for (i in 1:nLT) {  
+
+	    if(names(ETA)[i]=="")
+	    {
+	       	ETA[[i]]$Name=paste("ETA_",i,sep="")
+	    }else{
+               ETA[[i]]$Name=paste("ETA_",names(ETA)[i],sep="")
+	    }
+
             if (!(ETA[[i]]$model %in% c("FIXED", "BRR", "BL", "BayesA", "BayesB","BayesC", "RKHS","BRR_windows"))) 
             {
                 stop(paste(" Error in ETA[[", i, "]]", " model ", ETA[[i]]$model, " not implemented (note: evaluation is case sensitive).", sep = ""))
+                
             }
             ETA[[i]] = switch(ETA[[i]]$model, 
 			      FIXED = setLT.Fixed(LT = ETA[[i]],  n = n, j = i, weights = weights, y = y, nLT = nLT, saveAt = saveAt, rmExistingFiles = rmExistingFiles), 
@@ -1333,6 +1362,7 @@ BGLR=function (y, response_type = "gaussian", a = NULL, b = NULL,
 
                     if (ETA[[j]]$model == "RKHS") {
                       ETA[[j]]$post_varU = ETA[[j]]$post_varU * k + ETA[[j]]$varU/nSums
+                      ETA[[j]]$post_varU2 = ETA[[j]]$post_varU2 * k + (ETA[[j]]$varU^2)/nSums
                       ETA[[j]]$post_uStar = ETA[[j]]$post_uStar * k + ETA[[j]]$uStar/nSums
                       ETA[[j]]$post_u = ETA[[j]]$post_u * k + ETA[[j]]$u/nSums
                       ETA[[j]]$post_u2 = ETA[[j]]$post_u2 * k + (ETA[[j]]$u^2)/nSums
@@ -1518,7 +1548,8 @@ BGLR=function (y, response_type = "gaussian", a = NULL, b = NULL,
                ETA[[i]]$u=ETA[[i]]$post_u
                ETA[[i]]$uStar=ETA[[i]]$post_uStar
                ETA[[i]]$varU=ETA[[i]]$post_varU
-               tmp=which(names(ETA[[i]])%in%c("post_varU","post_uStar","post_u","post_u2"))
+               ETA[[i]]$SD.varU=sqrt(ETA[[i]]$post_varU2 - ETA[[i]]$post_varU^2)
+               tmp=which(names(ETA[[i]])%in%c("post_varU","post_varU2","post_uStar","post_u","post_u2"))
                ETA[[i]]=ETA[[i]][-tmp]
             }
 
